summaryrefslogtreecommitdiff
path: root/src/mongo/db/views
diff options
context:
space:
mode:
authorGrace Luong <grace.luong@mongodb.com>2020-07-08 21:29:09 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2020-07-09 00:07:45 +0000
commita2364e8742f0846b8143044d0511825319133049 (patch)
tree9b042e13edb3eae496c08cbd2982a15a78e2b574 /src/mongo/db/views
parentb0b09d66b99d80a0a65c4bc552b6e9f443aadb3b (diff)
downloadmongo-a2364e8742f0846b8143044d0511825319133049.tar.gz
SERVER-49060: updating generic FCV constants
Diffstat (limited to 'src/mongo/db/views')
-rw-r--r--src/mongo/db/views/view_catalog.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mongo/db/views/view_catalog.cpp b/src/mongo/db/views/view_catalog.cpp
index 1d2cdf66353..fb3cea60737 100644
--- a/src/mongo/db/views/view_catalog.cpp
+++ b/src/mongo/db/views/view_catalog.cpp
@@ -331,11 +331,11 @@ StatusWith<stdx::unordered_set<NamespaceString>> ViewCatalog::_validatePipeline(
// Save this to a variable to avoid reading the atomic variable multiple times.
auto currentFCV = serverGlobalParams.featureCompatibility.getVersion();
// If the feature compatibility version is not 4.6, and we are validating features as master,
// ban the use of new agg features introduced in 4.6 to prevent them from being persisted in the
// catalog.
if (serverGlobalParams.validateFeaturesAsMaster.load() &&
- currentFCV != ServerGlobalParams::FeatureCompatibility::Version::kFullyUpgradedTo46) {
+ currentFCV != ServerGlobalParams::FeatureCompatibility::kLatest) {
expCtx->maxFeatureCompatibilityVersion = currentFCV;
}
@@ -331,11 +331,11 @@ StatusWith<stdx::unordered_set<NamespaceString>> ViewCatalog::_validatePipeline(
// Save this to a variable to avoid reading the atomic variable multiple times.
auto currentFCV = serverGlobalParams.featureCompatibility.getVersion();
- // If the feature compatibility version is not 4.6, and we are validating features as master,
- // ban the use of new agg features introduced in 4.6 to prevent them from being persisted in the
- // catalog.
+ // If the feature compatibility version is not kLatest, and we are validating features as
+ // master, ban the use of new agg features introduced in kLatest to prevent them from being
+ // persisted in the catalog.
if (serverGlobalParams.validateFeaturesAsMaster.load() &&